"""Entry for ``python -m bumplus ...``."""
from __future__ import absolute_import, division, print_function

__import__("bumplus").main()
